unit Servers.Main;

interface

uses
  Winapi.Windows, Winapi.Messages, System.SysUtils, System.Variants, System.Classes, Vcl.Graphics,
  Vcl.Controls, Vcl.Forms, Vcl.Dialogs, Vcl.StdCtrls;

type
  TwndMain = class(TForm)
    ScrollActivos: TScrollBox;
    Button1: TButton;
    ScrollInactivos: TScrollBox;
    Button2: TButton;
    Label1: TLabel;
    Label2: TLabel;
    procedure Button1Click(Sender: TObject);
    procedure Button2Click(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
    procedure MoveFrame(Src, Dst:TScrollBox; lActive:Boolean);
    procedure FrameChangeStatus(Sender: TObject);

    procedure CreateServers(Scroll:TScrollBox);
    procedure AddServer(Scroll:TScrollBox;
                            AServerName,
                            AServerIP: String;
                            AServerActive: Boolean);

    function Ping(const AHost: string): Boolean;
  end;

var
  wndMain: TwndMain;

implementation

{$R *.dfm}

uses Servers.Frame, Vcl.WinXCtrls, IdIcmpClient, IdGlobal;

function TwndMain.Ping(const AHost: string): Boolean;
var
  MyIdIcmpClient : TIdIcmpClient;
begin
    Result := True;

    MyIdIcmpClient := TIdIcmpClient.Create(self);
    MyIdIcmpClient.ReceiveTimeout := 200;
    MyIdIcmpClient.Host := AHost;
    MyIdIcmpClient.PacketSize := 24;
    MyIdIcmpClient.Protocol := 1;
    MyIdIcmpClient.IPVersion := Id_IPv4;

    try
      MyIdIcmpClient.Ping;
      Sleep(250);
    except
      Result := False;
      Exit;
    end;

    if MyIdIcmpClient.ReplyStatus.ReplyStatusType <> rsEcho Then
       result := False;

    MyIdIcmpClient.Free;
end;

procedure TwndMain.AddServer(Scroll:TScrollBox;
                           AServerName,
                           AServerIP: String;
                           AServerActive: Boolean);
Var
  Frame:TFrameServer;

begin
     Frame:=TFrameServer.Create(Scroll,AServerName,AServerIP,AServerActive);
     Frame.Parent:=Scroll;
     Frame.Align:=TAlign.alTop;
     Frame.ToggleSwitch1.OnClick:=FrameChangeStatus;
end;

procedure TwndMain.CreateServers(Scroll:TScrollBox);
begin
     {Comentar si lees servidores de base de datos}
     AddServer(Scroll,'Atenea','192.168.1.2',true);
     AddServer(Scroll,'Zeus','192.168.1.3',false);
     AddServer(Scroll,'Ares','192.168.1.4',true);

     {Cdigo que crea tus servidores de acuerdo a consulta...}
{
     dm.q_Servidores.First;
     while dm.q_Servidores.Eof do
     begin
          AddServer(Scroll, dm.q_Servidores.FieldByName('nombre').AsString;
                            dm.q_Servidores.FieldByName('ipv4').AsString,
                            Ping(dm.q_Servidores.FieldByName('ipv4').AsString));


          dm.q_Servidores.Next;
     end;
}
     MoveFrame(ScrollActivos, ScrollInactivos, false);
     MoveFrame(ScrollInactivos, ScrollActivos, true);
end;

procedure TwndMain.Button1Click(Sender: TObject);
begin
     CreateServers(ScrollActivos);
end;

procedure TwndMain.MoveFrame(Src, Dst:TScrollBox; lActive:Boolean);
Var
  Frame, NewFrame:TFrameServer;
  AName:String;
  i:integer;
begin
     i:=0;
     while i<=Src.ComponentCount-1 do
     begin
          if Src.Components[i] Is TFrame then
          begin
               Frame:=(Src.Components[i] as TFrameServer);

               if Frame.ServerActive=lActive then
               begin
                    NewFrame:=TFrameServer.Create(Dst,
                                                  Frame.ServerName,
                                                  Frame.ServerIP,
                                                  Frame.ServerActive);
                    NewFrame.Parent:=Dst;
                    NewFrame.Align:=TAlign.alTop;
                    NewFrame.ToggleSwitch1.OnClick:=FrameChangeStatus;

                    AName:=Frame.Name;
                    Frame.Free;
                    NewFrame.Name:=AName;

                    Continue;
               end;
          end;
          inc(i);
     end;
end;

procedure TwndMain.Button2Click(Sender: TObject);
begin
     MoveFrame(ScrollActivos, ScrollInactivos, false);
     MoveFrame(ScrollInactivos, ScrollActivos, true);
end;

procedure TwndMain.FrameChangeStatus(Sender: TObject);
Var
  Frame:TFrameServer;
  Toogle:TToggleSwitch;
begin
     if not (Sender is TToggleSwitch) then
        Exit;

     Toogle:=TToggleSwitch(Sender);

     if not (Toogle.Parent Is TFrame) then
        Exit;

     Frame:=TFrameServer(Toogle.Parent);
     Frame.ServerActive:=not Frame.ServerActive;


     Frame.Refresh;

     MoveFrame(ScrollActivos, ScrollInactivos, false);
     MoveFrame(ScrollInactivos, ScrollActivos, true);

end;

end.
